#region File Description
//-----------------------------------------------------------------------------
// File:      Dialog.cs
// Namespace: WindowSystem
// Author:    Aaron MacDougall
//-----------------------------------------------------------------------------
#endregion

#region Using Statements
using System;
using Microsoft.Xna.Framework;
using InputEventSystem;
#endregion

namespace XNAWindowSystem
{
    /// <summary>
    /// Result of a dialog or message box.
    /// </summary>
    public enum DialogResult
    {
        OK,
        Cancel,
        Yes,
        No
    }

    /// <summary>
    /// A dialog box is a window that should return a value, defined by the
    /// DialogResult enumeration.
    /// </summary>
    public class Dialog : Window
    {
        #region Fields
        private DialogResult result;
        #endregion

        #region Properties
        /// <summary>
        /// Gets the result of the dialog box. Will return DialogResult.Cancel
        /// if called before dialog is closed.
        /// </summary>
        public DialogResult DialogResult
        {
            get { return this.result; }
        }
        #endregion

        #region Constructor
        /// <summary>
        /// Constructor.
        /// </summary>
        /// <param name="game">The currently running Game object.</param>
        /// <param name="guiManager">GUIManager that this control is part of.</param>
        public Dialog(Game game, GUIManager guiManager)
            : base(game, guiManager)
        {
            // The default result is cancel, because that is the result of the
            // user pressing the window close button.
            this.result = DialogResult.Cancel;
        }
        #endregion

        /// <summary>
        /// Used to set the dialog result before dialog closes.
        /// </summary>
        /// <param name="result">Dialog result.</param>
        protected void SetDialogResult(DialogResult result)
        {
            this.result = result;
        }
    }
}