#region File Description
//-----------------------------------------------------------------------------
// File:      Icon.cs
// Namespace: WindowSystem
// Author:    Aaron MacDougall
//-----------------------------------------------------------------------------
#endregion

#region Using Statements
using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
#endregion

namespace XNAWindowSystem
{
    /// <summary>
    /// A static image from the GUI texture. Can be scaled to fit the control
    /// size.
    /// </summary>
    public class Icon : SkinnedComponent
    {
        #region Fields
        private bool scale;
        #endregion

        #region Properties
        /// <summary>
        /// Get/Set whether the image be scaled to control size.
        /// </summary>
        public bool Scale
        {
            get { return this.scale; }
            set
            {
                this.scale = value;
                RefreshSkins();
            }
        }
        #endregion

        #region Constructors
        /// <summary>
        /// Constructor.
        /// </summary>
        /// <param name="game">The currently running Game object.</param>
        /// <param name="guiManager">GUIManager that this control is part of.</param>
        public Icon(Game game, GUIManager guiManager)
            : base(game, guiManager)
        {
            this.scale = false;
        }
        #endregion

        /// <summary>
        /// Resizes control to fit icon skin, as long as icon isn't scaling.
        /// </summary>
        public void ResizeToFit()
        {
            if (!this.scale)
            {
                int currentSkin = CurrentSkin;

                if (currentSkin != -1)
                {
                    Rectangle source = GetSkinLocation(currentSkin);

                    if (source.Width > 0 && source.Height > 0)
                    {
                        Width = source.Width;
                        Height = source.Height;
                    }
                }
            }
        }

        /// <summary>
        /// Update skin sizes.
        /// </summary>
        protected override void RefreshSkins()
        {
            // Get the current list of skins
            Dictionary<int, ComponentSkin> skins = Skins;

            foreach (KeyValuePair<int, ComponentSkin> skin in skins)
            {
                GUIRect rect = new GUIRect();
                rect.Source = GetSkinLocation(skin.Key);

                if (this.scale)
                    rect.Destination = new Rectangle(0, 0, Width, Height);
                else
                    rect.Destination = new Rectangle(0, 0, rect.Source.Width, rect.Source.Height);

                skin.Value.Rects.Clear();
                skin.Value.Rects.Add(rect);
            }

            Redraw();
        }
    }
}