#region File Description
//-----------------------------------------------------------------------------
// File:      Image.cs
// Namespace: WindowSystem
// Author:    Aaron MacDougall
//-----------------------------------------------------------------------------
#endregion

#region Using Statements
using System;
using System.Diagnostics;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
#endregion

namespace XNAWindowSystem
{
    /// <summary>
    /// A static image.
    /// </summary>
    public class Image : Icon
    {
        #region Properties
        /// <summary>
        /// Sets the texture image to use.
        /// </summary>
        /// <value>Must not be null.</value>
        public Texture2D Texture
        {
            set
            {
                Debug.Assert(value != null);

                // Set skin to use custom texture.
                // Assumes that only one skin will be applied.
                ComponentSkin skin = GetSkin(0);
                if (skin == null)
                    SkinLocation = new Rectangle(0, 0, value.Width, value.Height);

                skin = GetSkin(0);
                Debug.Assert(skin != null);
                
                skin.UseCustomSkin = true;
                skin.Skin = value;

                RefreshSkins();
            }
        }
        #endregion

        #region Constructors
        /// <summary>
        /// Constructor.
        /// </summary>
        /// <param name="game">The currently running Game object.</param>
        /// <param name="guiManager">GUIManager that this control is part of.</param>
        public Image(Game game, GUIManager guiManager)
            : base(game, guiManager)
        {
        }
        #endregion

        /// <summary>
        /// Clears the image.
        /// </summary>
        public void Reset()
        {
            CurrentSkin = -1;
            Redraw();
        }
    }
}