#region File Description
//-----------------------------------------------------------------------------
// File:      ImageButton.cs
// Namespace: WindowSystem
// Author:    Aaron MacDougall
//-----------------------------------------------------------------------------
#endregion

#region Using Statements
using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;
using InputEventSystem;
#endregion

namespace XNAWindowSystem
{
    /// <summary>
    /// A button comprised of seperate images for each state.
    /// </summary>
    public class ImageButton : Icon
    {
        #region Fields
        protected bool isChecked = false;
        #endregion

        #region Properties
        /// <summary>
        /// Get/Set whether the button is checked.
        /// </summary>
        public bool IsChecked
        {
            get { return isChecked; }
            set
            {
                this.isChecked = value;

                CurrentSkinState = SkinState.Normal;

                if (isChecked)
                    CurrentSkinState = SkinState.Checked;
            }
        }
        #endregion

        #region Constructor
        /// <summary>
        /// Constructor.
        /// </summary>
        /// <param name="game">The currently running Game object.</param>
        /// <param name="guiManager">GUIManager that this control is part of.</param>
        public ImageButton(Game game, GUIManager guiManager)
            : base(game, guiManager)
        {
            Scale = true;
        }
        #endregion

        #region Event Handlers
        /// <summary>
        /// Updates button skin to reflect current mouse state.
        /// </summary>
        /// <param name="args">Mouse event arguments.</param>
        protected override void OnMouseOver(MouseEventArgs args)
        {
            base.OnMouseOver(args);

            if (IsPressed)
            {
                CurrentSkinState = SkinState.Pressed;

                if (this.isChecked)
                    CurrentSkinState = SkinState.CheckedPressed;
            }
            else
            {
                CurrentSkinState = SkinState.Hover;

                if (this.isChecked)
                    CurrentSkinState = SkinState.CheckedHover;
            }
        }

        /// <summary>
        /// Updates button skin to reflect current mouse state.
        /// </summary>
        /// <param name="args">Mouse event arguments.</param>
        protected override void OnMouseOut(MouseEventArgs args)
        {
            base.OnMouseOut(args);

            CurrentSkinState = SkinState.Normal;

            if (this.isChecked)
                CurrentSkinState = SkinState.Checked;
        }

        /// <summary>
        /// Updates button skin to reflect current mouse state.
        /// </summary>
        /// <param name="args">Mouse event arguments.</param>
        protected override void OnMouseDown(MouseEventArgs args)
        {
            base.OnMouseDown(args);

            if (args.Button == MouseButtons.Left)
            {
                CurrentSkinState = SkinState.Pressed;

                if (this.isChecked)
                    CurrentSkinState = SkinState.CheckedPressed;
            }
        }

        /// <summary>
        /// Updates button skin to reflect current mouse state.
        /// </summary>
        /// <param name="args">Mouse event arguments.</param>
        protected override void OnMouseUp(MouseEventArgs args)
        {
            if (args.Button == MouseButtons.Left)
            {
                // Check that the mouse was depressed inside the button
                if (CheckCoordinates(args.Position.X, args.Position.Y))
                {
                    this.isChecked = !this.isChecked;

                    CurrentSkinState = SkinState.Hover;

                    if (this.isChecked)
                        CurrentSkinState = SkinState.CheckedHover;
                }
                else
                {
                    CurrentSkinState = SkinState.Normal;

                    if (this.isChecked)
                        CurrentSkinState = SkinState.Checked;
                }
            }

            base.OnMouseUp(args);
        }
        #endregion
    }
}